# Generated by Django 3.1.2 on 2021-04-13 18:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0015_add_aka_longname"),
    ]

    operations = [
        migrations.AddField(
            model_name="internetexchange",
            name="service_level",
            field=models.CharField(
                blank=True,
                choices=[
                    ("", "Not Disclosed"),
                    ("Not Disclosed", "Not Disclosed"),
                    ("Best Effort (no SLA)", "Best Effort (no SLA)"),
                    ("Normal Business Hours", "Normal Business Hours"),
                    ("24/7 Support", "24/7 Support"),
                ],
                default="Not Disclosed",
                max_length=60,
                verbose_name="Service Level",
            ),
        ),
        migrations.AddField(
            model_name="internetexchange",
            name="terms",
            field=models.CharField(
                blank=True,
                choices=[
                    ("", "Not Disclosed"),
                    ("Not Disclosed", "Not Disclosed"),
                    ("No Commercial Terms", "No Commercial Terms"),
                    ("Bundled With Other Services", "Bundled With Other Services"),
                    ("Non-recurring Fees Only", "Non-recurring Fees Only"),
                    ("Recurring Fees", "Recurring Fees"),
                ],
                default="Not Disclosed",
                max_length=60,
                verbose_name="Terms",
            ),
        ),
    ]
