# Generated by Django 3.2.9 on 2022-02-02 13:59

import django.core.validators
import django_inet.models
from django.db import migrations, models

import django_peeringdb.models.abstract


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0019_ix_add_sales_phone_email"),
    ]

    operations = [
        migrations.AddField(
            model_name="facility",
            name="status_dashboard",
            field=django_peeringdb.models.abstract.URLField(
                blank=True, max_length=255, null=True, verbose_name="Status Dashboard"
            ),
        ),
        migrations.AddField(
            model_name="internetexchange",
            name="status_dashboard",
            field=django_peeringdb.models.abstract.URLField(
                blank=True, max_length=255, null=True, verbose_name="Status Dashboard"
            ),
        ),
        migrations.AddField(
            model_name="network",
            name="status_dashboard",
            field=django_peeringdb.models.abstract.URLField(
                blank=True, max_length=255, null=True, verbose_name="Status Dashboard"
            ),
        ),
    ]
