# Generated by Django 3.1.2 on 2020-11-17 23:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0012_change_network_prefixes_and_info_type"),
    ]

    operations = [
        migrations.AlterField(
            model_name="networkcontact",
            name="phone",
            field=models.CharField(
                blank=True,
                help_text="An E.164-formatted phone number starts with a +, followed by the country code, then the national phone number (dropping the leading 0 in most countries), without spaces or dashes between the groups of digits",
                max_length=100,
                verbose_name="Phone",
            ),
        ),
        migrations.AlterField(
            model_name="facility",
            name="sales_phone",
            field=models.CharField(
                blank=True,
                help_text="An E.164-formatted phone number starts with a +, followed by the country code, then the national phone number (dropping the leading 0 in most countries), without spaces or dashes between the groups of digits",
                max_length=192,
                verbose_name="Sales Phone",
            ),
        ),
        migrations.AlterField(
            model_name="facility",
            name="tech_phone",
            field=models.CharField(
                blank=True,
                help_text="An E.164-formatted phone number starts with a +, followed by the country code, then the national phone number (dropping the leading 0 in most countries), without spaces or dashes between the groups of digits",
                max_length=192,
                verbose_name="Technical Phone",
            ),
        ),
        migrations.AlterField(
            model_name="internetexchange",
            name="policy_phone",
            field=models.CharField(
                blank=True,
                help_text="An E.164-formatted phone number starts with a +, followed by the country code, then the national phone number (dropping the leading 0 in most countries), without spaces or dashes between the groups of digits",
                max_length=192,
                verbose_name="Policy Phone",
            ),
        ),
        migrations.AlterField(
            model_name="internetexchange",
            name="tech_phone",
            field=models.CharField(
                blank=True,
                help_text="An E.164-formatted phone number starts with a +, followed by the country code, then the national phone number (dropping the leading 0 in most countries), without spaces or dashes between the groups of digits",
                max_length=192,
                verbose_name="Technical Phone",
            ),
        ),
    ]
