# Generated by Django 3.2.13 on 2022-06-20 05:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0020_status_dashboard"),
    ]

    operations = [
        migrations.AddField(
            model_name="network",
            name="rir_status",
            field=models.CharField(
                default=None, max_length=255, null=True, verbose_name="RIR status"
            ),
        ),
        migrations.AddField(
            model_name="network",
            name="rir_status_updated",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="RIR status updated"
            ),
        ),
    ]
