# Generated by Django 2.2.12 on 2020-05-01 16:17

import django.db.models.deletion
import django_countries.fields
import django_inet.models
from django.db import migrations, models

import django_peeringdb.models.abstract


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0006_net_operational"),
    ]

    operations = []
