# Generated by Django 3.2.7 on 2021-10-02 00:54

import django.core.validators
import django_inet.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0018_add_region_continent_field"),
    ]

    operations = [
        migrations.AddField(
            model_name="internetexchange",
            name="sales_email",
            field=models.EmailField(
                blank=True, max_length=254, verbose_name="Sales Email"
            ),
        ),
        migrations.AddField(
            model_name="internetexchange",
            name="sales_phone",
            field=models.CharField(
                blank=True,
                help_text="An E.164-formatted phone number starts with a +, followed by the country code, then the national phone number (dropping the leading 0 in most countries), without spaces or dashes between the groups of digits",
                max_length=192,
                verbose_name="Sales Phone",
            ),
        ),
    ]
