# Generated by Django 3.1.2 on 2021-03-05 18:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0014_add_suite_and_floor"),
    ]

    operations = [
        # Facilities need "name_long" and "aka"
        migrations.AddField(
            model_name="facility",
            name="aka",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Also Known As"
            ),
        ),
        migrations.AddField(
            model_name="facility",
            name="name_long",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Long Name"
            ),
        ),
        # Internet Exchange already has "name_long," although we alter the max_length
        migrations.AlterField(
            model_name="internetexchange",
            name="name_long",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Long Name"
            ),
        ),
        migrations.AddField(
            model_name="internetexchange",
            name="aka",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Also Known As"
            ),
        ),
        # Network already has "aka"
        migrations.AddField(
            model_name="network",
            name="name_long",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Long Name"
            ),
        ),
        # Organization needs "aka" and "name_long"
        migrations.AddField(
            model_name="organization",
            name="aka",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Also Known As"
            ),
        ),
        migrations.AddField(
            model_name="organization",
            name="name_long",
            field=models.CharField(
                blank=True, max_length=255, verbose_name="Long Name"
            ),
        ),
    ]
