# Generated by Django 2.2.12 on 2020-04-03 20:40

from django.db import migrations

import django_peeringdb.models.abstract


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0003_never_via_route_servers"),
    ]

    operations = [
        migrations.AlterField(
            model_name="network",
            name="looking_glass",
            field=django_peeringdb.models.abstract.LG_URLField(
                blank=True, max_length=255
            ),
        ),
        migrations.AlterField(
            model_name="network",
            name="route_server",
            field=django_peeringdb.models.abstract.LG_URLField(
                blank=True, max_length=255
            ),
        ),
    ]
