# Generated by Django 2.2.12 on 2020-07-10 13:33

import django.db.models.deletion
import django_countries.fields
import django_inet.models
from django.db import migrations, models

import django_peeringdb.models.abstract


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0009_ixlanprefix_in_dfz"),
    ]

    operations = [
        migrations.AddField(
            model_name="internetexchange",
            name="ixf_last_import",
            field=models.DateTimeField(
                blank=True, null=True, verbose_name="IX-F Last Import"
            ),
        ),
        migrations.AddField(
            model_name="internetexchange",
            name="ixf_net_count",
            field=models.IntegerField(default=0, verbose_name="IX-F Network Count"),
        ),
    ]
