# Generated by Django 2.2.12 on 2020-05-13 08:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_peeringdb", "0008_traffic_levels"),
    ]

    operations = [
        migrations.AddField(
            model_name="ixlanprefix",
            name="in_dfz",
            field=models.BooleanField(default=False),
        ),
    ]
